@@ -31,6 +31,7 @@ import org.kie.workbench.client.navigation.NavTreeDefinitions;
 import org.kie.workbench.common.workbench.client.admin.DefaultAdminPageHelper;
 import org.kie.workbench.common.workbench.client.authz.PermissionTreeSetup;
 import org.kie.workbench.common.workbench.client.entrypoint.DefaultWorkbenchEntryPoint;
+import org.kie.workbench.common.workbench.client.error.DefaultWorkbenchErrorCallback;
 import org.kie.workbench.common.workbench.client.menu.DefaultWorkbenchFeaturesMenusHelper;
 import org.uberfire.client.mvp.ActivityBeansCache;
 import org.uberfire.client.workbench.Workbench;
@@ -75,9 +76,11 @@ public class KieWorkbenchEntryPoint extends DefaultWorkbenchEntryPoint {
                                   final DefaultAdminPageHelper adminPageHelper,
                                   final NavTreeDefinitions navTreeDefinitions,
                                   final NavigationManager navigationManager,
-                                  final NavigationExplorerScreen navigationExplorerScreen) {
+                                  final NavigationExplorerScreen navigationExplorerScreen,
+                                  final DefaultWorkbenchErrorCallback defaultWorkbenchErrorCallback) {
         super(appConfigService,
-              activityBeansCache);
+              activityBeansCache,
+              defaultWorkbenchErrorCallback);
         this.menusHelper = menusHelper;
         this.userSystemManager = userSystemManager;
         this.menuBar = menuBar;
@@ -92,11 +95,16 @@ public class KieWorkbenchEntryPoint extends DefaultWorkbenchEntryPoint {
     @PostConstruct
     public void init() {
         workbench.addStartupBlocker(KieWorkbenchEntryPoint.class);
-        permissionTreeSetup.configureTree();
 
         initNavTreeEditor();
     }
 
+    @Override
+    protected void initializeWorkbench() {
+        permissionTreeSetup.configureTree();
+        super.initializeWorkbench();
+    }
+
     @Override
     public void setupMenu() {
         navigationManager.init(() -> {
